#[repr(transparent)]pub struct Pfd480Tog(pub u32);Expand description
480MHz Clock (PLL3) Phase Fractional Divider Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Pfd480Tog
impl Pfd480Tog
Sourcepub const fn set_pfd0_frac(&mut self, val: u8)
pub const fn set_pfd0_frac(&mut self, val: u8)
This field controls the fractional divide value
Sourcepub const fn pfd0_stable(&self) -> bool
pub const fn pfd0_stable(&self) -> bool
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn set_pfd0_stable(&mut self, val: bool)
pub const fn set_pfd0_stable(&mut self, val: bool)
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn pfd0_clkgate(&self) -> bool
pub const fn pfd0_clkgate(&self) -> bool
If set to 1, the IO fractional divider clock (reference ref_pfd0) is off (power savings)
Sourcepub const fn set_pfd0_clkgate(&mut self, val: bool)
pub const fn set_pfd0_clkgate(&mut self, val: bool)
If set to 1, the IO fractional divider clock (reference ref_pfd0) is off (power savings)
Sourcepub const fn set_pfd1_frac(&mut self, val: u8)
pub const fn set_pfd1_frac(&mut self, val: u8)
This field controls the fractional divide value
Sourcepub const fn pfd1_stable(&self) -> bool
pub const fn pfd1_stable(&self) -> bool
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn set_pfd1_stable(&mut self, val: bool)
pub const fn set_pfd1_stable(&mut self, val: bool)
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn pfd1_clkgate(&self) -> bool
pub const fn pfd1_clkgate(&self) -> bool
IO Clock Gate
Sourcepub const fn set_pfd1_clkgate(&mut self, val: bool)
pub const fn set_pfd1_clkgate(&mut self, val: bool)
IO Clock Gate
Sourcepub const fn set_pfd2_frac(&mut self, val: u8)
pub const fn set_pfd2_frac(&mut self, val: u8)
This field controls the fractional divide value
Sourcepub const fn pfd2_stable(&self) -> bool
pub const fn pfd2_stable(&self) -> bool
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn set_pfd2_stable(&mut self, val: bool)
pub const fn set_pfd2_stable(&mut self, val: bool)
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn pfd2_clkgate(&self) -> bool
pub const fn pfd2_clkgate(&self) -> bool
IO Clock Gate
Sourcepub const fn set_pfd2_clkgate(&mut self, val: bool)
pub const fn set_pfd2_clkgate(&mut self, val: bool)
IO Clock Gate
Sourcepub const fn set_pfd3_frac(&mut self, val: u8)
pub const fn set_pfd3_frac(&mut self, val: u8)
This field controls the fractional divide value
Sourcepub const fn pfd3_stable(&self) -> bool
pub const fn pfd3_stable(&self) -> bool
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn set_pfd3_stable(&mut self, val: bool)
pub const fn set_pfd3_stable(&mut self, val: bool)
This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code
Sourcepub const fn pfd3_clkgate(&self) -> bool
pub const fn pfd3_clkgate(&self) -> bool
IO Clock Gate
Sourcepub const fn set_pfd3_clkgate(&mut self, val: bool)
pub const fn set_pfd3_clkgate(&mut self, val: bool)
IO Clock Gate